<?php

namespace Drupal\fleetview_client\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure pants settings for this site.
 */
class FleetviewClientSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fleetview_client_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('fleetview_client.settings');

    $form['fleetview_client_service'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Connection token'),
      '#description' => $config->get('fleetview_client_token') . "-" . $config->get('fleetview_client_encrypt_token'),
      '#default_value' => $config->get('fleetview_client_token') . "-" . $config->get('fleetview_client_encrypt_token'),
      '#attributes' => ['style' => ['display:none;']],
      '#size' => 60,
      '#maxlength' => 60,
      '#disabled' => TRUE,
    ];

    $form['fleetview_client_service_allow_external'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow external services to fetch this site'),
      '#description' => $this->t('Allow reports to be generated by external services. <br>All information will be sent using encryption and is only accessible using your siteUUID.'),
      '#default_value' => TRUE,
      '#disabled' => TRUE,
      '#default_value' => $config->get('fleetview_client_service_allow_external'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['fleetview_client.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('fleetview_client.settings')
      ->set('fleetview_client_service_allow_external', $form_state->getValue('fleetview_client_service_allow_external'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
